{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": false,
    "hidePrompt": false,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Neurons example with stim types\n",
    "## Generate some data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "hideCode": false,
    "hidePrompt": false,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [],
   "source": [
    "from bayes_window import models, fake_spikes_explore, BayesWindow, BayesRegression\n",
    "from bayes_window.generative_models import generate_fake_spikes,generate_spikes_stim_types\n",
    "from importlib import reload\n",
    "import numpy as np\n",
    "import altair as alt"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "hideCode": false,
    "hidePrompt": false,
    "lines_to_next_cell": 2,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [],
   "source": [
    "df = generate_spikes_stim_types(mouse_response_slope=3,\n",
    "                                n_trials=2,\n",
    "                                n_neurons=3,\n",
    "                                n_mice=4,\n",
    "                                dur=2, )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "hideCode": false,
    "hidePrompt": false,
    "lines_to_next_cell": 2,
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2021-11-30 14:40:24.568367: E external/org_tensorflow/tensorflow/stream_executor/cuda/cuda_driver.cc:271] failed call to cuInit: CUDA_ERROR_COMPAT_NOT_SUPPORTED_ON_DEVICE: forward compatibility was attempted on non supported HW\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "<bayes_window.slopes.BayesRegression at 0x7ff1f9dfeac0>"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "\n",
    "window = BayesRegression(df=df, y='isi', treatment='stim', condition=['stim_strength','neuron_x_mouse'],\n",
    "                              group='mouse')\n",
    "window.fit(model=models.model_hierarchical)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-dc0f592460c14145bec9f1087ed05a9d\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-dc0f592460c14145bec9f1087ed05a9d\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-dc0f592460c14145bec9f1087ed05a9d\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"vconcat\": [{\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 0\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 1\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 10\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 11\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 2\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 3\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 4\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 5\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 6\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 7\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 8\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 9\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}], \"data\": {\"name\": \"data-0cce97b548538fd689d7a149c308dd23\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-0cce97b548538fd689d7a149c308dd23\": [{\"stim_strength\": 0, \"neuron_x_mouse\": \"0\", \"mouse\": \"0\", \"combined_condition\": 0, \"isi diff\": 0.024497842310564982, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": 0.021878531202673912, \"sigma_intercept_per_group lower interval\": 0.003589517902582884, \"sigma_intercept_per_group center interval\": 0.01025201566517353, \"sigma_obs higher interval\": 0.029004130512475967, \"sigma_obs lower interval\": 0.020831281319260597, \"sigma_obs center interval\": 0.02476665936410427, \"sigma_slope_per_condition higher interval\": 0.00023495976347476244, \"sigma_slope_per_condition lower interval\": 1.265212176804198e-06, \"sigma_slope_per_condition center interval\": 0.00013006216613575816, \"higher interval\": 223.27513122558594, \"lower interval\": -94.46192932128906, \"center interval\": 86.77113310992718, \"higher interval75\": 144.5200958251953, \"lower interval75\": -36.55290985107422, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"1\", \"mouse\": \"0\", \"combined_condition\": 1, \"isi diff\": 0.0008015253805313538, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 141.4018096923828, \"lower interval\": -193.2095489501953, \"center interval\": 8.340732365846634, \"higher interval75\": 78.49813079833984, \"lower interval75\": -116.08368682861328, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"2\", \"mouse\": \"0\", \"combined_condition\": 2, \"isi diff\": 0.01536468841076917, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 178.7096710205078, \"lower interval\": -129.21405029296875, \"center interval\": 32.476514026522636, \"higher interval75\": 103.55020141601562, \"lower interval75\": -75.07167053222656, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"3\", \"mouse\": \"1\", \"combined_condition\": 3, \"isi diff\": -0.0050254140254095, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 174.48736572265625, \"lower interval\": -141.3601531982422, \"center interval\": 26.883456200361252, \"higher interval75\": 102.13192749023438, \"lower interval75\": -79.98334503173828, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"4\", \"mouse\": \"1\", \"combined_condition\": 4, \"isi diff\": 0.021413873717857038, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 163.26068115234375, \"lower interval\": -142.33265686035156, \"center interval\": 15.469324380159378, \"higher interval75\": 96.27157592773438, \"lower interval75\": -92.8603744506836, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"5\", \"mouse\": \"1\", \"combined_condition\": 5, \"isi diff\": 0.028978285633282586, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 170.3251953125, \"lower interval\": -145.4585418701172, \"center interval\": 8.261808276176453, \"higher interval75\": 119.76193237304688, \"lower interval75\": -65.5672378540039, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"6\", \"mouse\": \"2\", \"combined_condition\": 6, \"isi diff\": 0.028851849976881894, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 257.19171142578125, \"lower interval\": -86.87279510498047, \"center interval\": 98.48909559845924, \"higher interval75\": 202.93031311035156, \"lower interval75\": 16.100181579589844, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"7\", \"mouse\": \"2\", \"combined_condition\": 7, \"isi diff\": 0.003042558376887966, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 164.2918243408203, \"lower interval\": -150.91183471679688, \"center interval\": 38.393189400434494, \"higher interval75\": 103.52960205078125, \"lower interval75\": -79.03858947753906, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"8\", \"mouse\": \"2\", \"combined_condition\": 8, \"isi diff\": -0.004726216869305536, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 129.72628784179688, \"lower interval\": -212.55699157714844, \"center interval\": -68.44467642903328, \"higher interval75\": 51.500919342041016, \"lower interval75\": -135.76443481445312, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"9\", \"mouse\": \"3\", \"combined_condition\": 9, \"isi diff\": -0.05324052547347448, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 158.19837951660156, \"lower interval\": -178.42848205566406, \"center interval\": 0.3554098904132843, \"higher interval75\": 81.5319595336914, \"lower interval75\": -110.55287170410156, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"10\", \"mouse\": \"3\", \"combined_condition\": 10, \"isi diff\": 0.00826907049542587, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 154.79470825195312, \"lower interval\": -170.1979217529297, \"center interval\": 28.262607499957085, \"higher interval75\": 96.89962005615234, \"lower interval75\": -101.59248352050781, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"11\", \"mouse\": \"3\", \"combined_condition\": 11, \"isi diff\": 0.0058104385023158706, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 130.77212524414062, \"lower interval\": -207.31813049316406, \"center interval\": -43.42920449376106, \"higher interval75\": 57.44569396972656, \"lower interval75\": -119.93888092041016, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"0\", \"mouse\": \"0\", \"combined_condition\": 12, \"isi diff\": 0.0019820891335522867, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 227.3662872314453, \"lower interval\": -112.50251007080078, \"center interval\": 53.711196541786194, \"higher interval75\": 151.1462860107422, \"lower interval75\": -39.064571380615234, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"1\", \"mouse\": \"0\", \"combined_condition\": 13, \"isi diff\": -0.009391310911386078, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 137.10658264160156, \"lower interval\": -162.7246551513672, \"center interval\": -6.996676504611969, \"higher interval75\": 80.00298309326172, \"lower interval75\": -93.04759979248047, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"2\", \"mouse\": \"0\", \"combined_condition\": 14, \"isi diff\": 0.01448439419979676, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 139.16830444335938, \"lower interval\": -182.70999145507812, \"center interval\": -11.28330060839653, \"higher interval75\": 65.94517517089844, \"lower interval75\": -113.74998474121094, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"3\", \"mouse\": \"1\", \"combined_condition\": 15, \"isi diff\": 0.06652380819514873, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 368.8595275878906, \"lower interval\": -21.046810150146484, \"center interval\": 195.96086801588535, \"higher interval75\": 285.610107421875, \"lower interval75\": 74.91966247558594, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"4\", \"mouse\": \"1\", \"combined_condition\": 16, \"isi diff\": 0.004756856483863606, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 139.74632263183594, \"lower interval\": -182.9421844482422, \"center interval\": -31.428532421588898, \"higher interval75\": 50.46245574951172, \"lower interval75\": -127.0048599243164, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"5\", \"mouse\": \"1\", \"combined_condition\": 17, \"isi diff\": -0.029547284066656576, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 88.4240951538086, \"lower interval\": -217.3368682861328, \"center interval\": -48.259985476732254, \"higher interval75\": 35.10549545288086, \"lower interval75\": -137.89952087402344, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"6\", \"mouse\": \"2\", \"combined_condition\": 18, \"isi diff\": 0.0009528798658254567, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 171.53799438476562, \"lower interval\": -150.21188354492188, \"center interval\": 21.218051329255104, \"higher interval75\": 118.83638763427734, \"lower interval75\": -64.80076599121094, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"7\", \"mouse\": \"2\", \"combined_condition\": 19, \"isi diff\": -0.0016507383145400178, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 162.42837524414062, \"lower interval\": -162.69619750976562, \"center interval\": -9.770642951130867, \"higher interval75\": 82.75050354003906, \"lower interval75\": -109.62390899658203, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"8\", \"mouse\": \"2\", \"combined_condition\": 20, \"isi diff\": -0.009927757586937078, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 132.20095825195312, \"lower interval\": -209.9013214111328, \"center interval\": -43.79651939868927, \"higher interval75\": 69.97917938232422, \"lower interval75\": -119.87165069580078, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"9\", \"mouse\": \"3\", \"combined_condition\": 21, \"isi diff\": -0.04329791741784626, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 168.93179321289062, \"lower interval\": -155.18756103515625, \"center interval\": 2.656790867447853, \"higher interval75\": 110.3091812133789, \"lower interval75\": -67.53697967529297, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"10\", \"mouse\": \"3\", \"combined_condition\": 22, \"isi diff\": -0.019854298382858834, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 99.099609375, \"lower interval\": -211.92425537109375, \"center interval\": -21.041308641433716, \"higher interval75\": 53.91379165649414, \"lower interval75\": -131.060791015625, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"11\", \"mouse\": \"3\", \"combined_condition\": 23, \"isi diff\": 0.007359094120306421, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 117.85163879394531, \"lower interval\": -207.75613403320312, \"center interval\": -50.186931416392326, \"higher interval75\": 22.130416870117188, \"lower interval75\": -156.6006622314453, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "window.plot(x='stim_strength',column='mouse',independent_axes=False,row='neuron_x_mouse')\n",
    "# window.chart_posterior_hdi"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-3b2ce3bec6a24fd7b969780194360b19\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-3b2ce3bec6a24fd7b969780194360b19\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-3b2ce3bec6a24fd7b969780194360b19\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"vconcat\": [{\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 0\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 1\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 10\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 11\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 0 neuron_x_mouse 2\", \"transform\": [{\"filter\": \"(datum['mouse'] === '0')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 3\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 4\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 1 neuron_x_mouse 5\", \"transform\": [{\"filter\": \"(datum['mouse'] === '1')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 6\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 7\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 2 neuron_x_mouse 8\", \"transform\": [{\"filter\": \"(datum['mouse'] === '2')\"}], \"width\": 80}]}, {\"hconcat\": [{\"layer\": [{\"layer\": [{\"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.7, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 2}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-217.3368682861328, 368.8595275878906], \"zero\": true}}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}, {\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.04123532241516781, 0.028959320284822482], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}}], \"height\": 150, \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"title\": \"mouse 3 neuron_x_mouse 9\", \"transform\": [{\"filter\": \"(datum['mouse'] === '3')\"}], \"width\": 80}]}], \"data\": {\"name\": \"data-0cce97b548538fd689d7a149c308dd23\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-0cce97b548538fd689d7a149c308dd23\": [{\"stim_strength\": 0, \"neuron_x_mouse\": \"0\", \"mouse\": \"0\", \"combined_condition\": 0, \"isi diff\": 0.024497842310564982, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": 0.021878531202673912, \"sigma_intercept_per_group lower interval\": 0.003589517902582884, \"sigma_intercept_per_group center interval\": 0.01025201566517353, \"sigma_obs higher interval\": 0.029004130512475967, \"sigma_obs lower interval\": 0.020831281319260597, \"sigma_obs center interval\": 0.02476665936410427, \"sigma_slope_per_condition higher interval\": 0.00023495976347476244, \"sigma_slope_per_condition lower interval\": 1.265212176804198e-06, \"sigma_slope_per_condition center interval\": 0.00013006216613575816, \"higher interval\": 223.27513122558594, \"lower interval\": -94.46192932128906, \"center interval\": 86.77113310992718, \"higher interval75\": 144.5200958251953, \"lower interval75\": -36.55290985107422, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"1\", \"mouse\": \"0\", \"combined_condition\": 1, \"isi diff\": 0.0008015253805313538, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 141.4018096923828, \"lower interval\": -193.2095489501953, \"center interval\": 8.340732365846634, \"higher interval75\": 78.49813079833984, \"lower interval75\": -116.08368682861328, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"2\", \"mouse\": \"0\", \"combined_condition\": 2, \"isi diff\": 0.01536468841076917, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 178.7096710205078, \"lower interval\": -129.21405029296875, \"center interval\": 32.476514026522636, \"higher interval75\": 103.55020141601562, \"lower interval75\": -75.07167053222656, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"3\", \"mouse\": \"1\", \"combined_condition\": 3, \"isi diff\": -0.0050254140254095, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 174.48736572265625, \"lower interval\": -141.3601531982422, \"center interval\": 26.883456200361252, \"higher interval75\": 102.13192749023438, \"lower interval75\": -79.98334503173828, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"4\", \"mouse\": \"1\", \"combined_condition\": 4, \"isi diff\": 0.021413873717857038, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 163.26068115234375, \"lower interval\": -142.33265686035156, \"center interval\": 15.469324380159378, \"higher interval75\": 96.27157592773438, \"lower interval75\": -92.8603744506836, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"5\", \"mouse\": \"1\", \"combined_condition\": 5, \"isi diff\": 0.028978285633282586, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 170.3251953125, \"lower interval\": -145.4585418701172, \"center interval\": 8.261808276176453, \"higher interval75\": 119.76193237304688, \"lower interval75\": -65.5672378540039, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"6\", \"mouse\": \"2\", \"combined_condition\": 6, \"isi diff\": 0.028851849976881894, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 257.19171142578125, \"lower interval\": -86.87279510498047, \"center interval\": 98.48909559845924, \"higher interval75\": 202.93031311035156, \"lower interval75\": 16.100181579589844, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"7\", \"mouse\": \"2\", \"combined_condition\": 7, \"isi diff\": 0.003042558376887966, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 164.2918243408203, \"lower interval\": -150.91183471679688, \"center interval\": 38.393189400434494, \"higher interval75\": 103.52960205078125, \"lower interval75\": -79.03858947753906, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"8\", \"mouse\": \"2\", \"combined_condition\": 8, \"isi diff\": -0.004726216869305536, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 129.72628784179688, \"lower interval\": -212.55699157714844, \"center interval\": -68.44467642903328, \"higher interval75\": 51.500919342041016, \"lower interval75\": -135.76443481445312, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"9\", \"mouse\": \"3\", \"combined_condition\": 9, \"isi diff\": -0.05324052547347448, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 158.19837951660156, \"lower interval\": -178.42848205566406, \"center interval\": 0.3554098904132843, \"higher interval75\": 81.5319595336914, \"lower interval75\": -110.55287170410156, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"10\", \"mouse\": \"3\", \"combined_condition\": 10, \"isi diff\": 0.00826907049542587, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 154.79470825195312, \"lower interval\": -170.1979217529297, \"center interval\": 28.262607499957085, \"higher interval75\": 96.89962005615234, \"lower interval75\": -101.59248352050781, \"zero\": 0}, {\"stim_strength\": 0, \"neuron_x_mouse\": \"11\", \"mouse\": \"3\", \"combined_condition\": 11, \"isi diff\": 0.0058104385023158706, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 130.77212524414062, \"lower interval\": -207.31813049316406, \"center interval\": -43.42920449376106, \"higher interval75\": 57.44569396972656, \"lower interval75\": -119.93888092041016, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"0\", \"mouse\": \"0\", \"combined_condition\": 12, \"isi diff\": 0.0019820891335522867, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 227.3662872314453, \"lower interval\": -112.50251007080078, \"center interval\": 53.711196541786194, \"higher interval75\": 151.1462860107422, \"lower interval75\": -39.064571380615234, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"1\", \"mouse\": \"0\", \"combined_condition\": 13, \"isi diff\": -0.009391310911386078, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 137.10658264160156, \"lower interval\": -162.7246551513672, \"center interval\": -6.996676504611969, \"higher interval75\": 80.00298309326172, \"lower interval75\": -93.04759979248047, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"2\", \"mouse\": \"0\", \"combined_condition\": 14, \"isi diff\": 0.01448439419979676, \"mu_intercept_per_group higher interval\": 13.237592697143555, \"mu_intercept_per_group lower interval\": 1.9029710292816162, \"mu_intercept_per_group center interval\": 5.481683191435877, \"mu_intercept_per_group higher interval75\": 10.360755920410156, \"mu_intercept_per_group lower interval75\": 3.007732629776001, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 139.16830444335938, \"lower interval\": -182.70999145507812, \"center interval\": -11.28330060839653, \"higher interval75\": 65.94517517089844, \"lower interval75\": -113.74998474121094, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"3\", \"mouse\": \"1\", \"combined_condition\": 15, \"isi diff\": 0.06652380819514873, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 368.8595275878906, \"lower interval\": -21.046810150146484, \"center interval\": 195.96086801588535, \"higher interval75\": 285.610107421875, \"lower interval75\": 74.91966247558594, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"4\", \"mouse\": \"1\", \"combined_condition\": 16, \"isi diff\": 0.004756856483863606, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 139.74632263183594, \"lower interval\": -182.9421844482422, \"center interval\": -31.428532421588898, \"higher interval75\": 50.46245574951172, \"lower interval75\": -127.0048599243164, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"5\", \"mouse\": \"1\", \"combined_condition\": 17, \"isi diff\": -0.029547284066656576, \"mu_intercept_per_group higher interval\": 15.3120698928833, \"mu_intercept_per_group lower interval\": 2.279677152633667, \"mu_intercept_per_group center interval\": 7.24303828610573, \"mu_intercept_per_group higher interval75\": 11.666829109191895, \"mu_intercept_per_group lower interval75\": 3.5302886962890625, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 88.4240951538086, \"lower interval\": -217.3368682861328, \"center interval\": -48.259985476732254, \"higher interval75\": 35.10549545288086, \"lower interval75\": -137.89952087402344, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"6\", \"mouse\": \"2\", \"combined_condition\": 18, \"isi diff\": 0.0009528798658254567, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 171.53799438476562, \"lower interval\": -150.21188354492188, \"center interval\": 21.218051329255104, \"higher interval75\": 118.83638763427734, \"lower interval75\": -64.80076599121094, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"7\", \"mouse\": \"2\", \"combined_condition\": 19, \"isi diff\": -0.0016507383145400178, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 162.42837524414062, \"lower interval\": -162.69619750976562, \"center interval\": -9.770642951130867, \"higher interval75\": 82.75050354003906, \"lower interval75\": -109.62390899658203, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"8\", \"mouse\": \"2\", \"combined_condition\": 20, \"isi diff\": -0.009927757586937078, \"mu_intercept_per_group higher interval\": 14.662755966186523, \"mu_intercept_per_group lower interval\": 2.289320230484009, \"mu_intercept_per_group center interval\": 6.724279347807169, \"mu_intercept_per_group higher interval75\": 11.951086044311523, \"mu_intercept_per_group lower interval75\": 3.716658353805542, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 132.20095825195312, \"lower interval\": -209.9013214111328, \"center interval\": -43.79651939868927, \"higher interval75\": 69.97917938232422, \"lower interval75\": -119.87165069580078, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"9\", \"mouse\": \"3\", \"combined_condition\": 21, \"isi diff\": -0.04329791741784626, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 168.93179321289062, \"lower interval\": -155.18756103515625, \"center interval\": 2.656790867447853, \"higher interval75\": 110.3091812133789, \"lower interval75\": -67.53697967529297, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"10\", \"mouse\": \"3\", \"combined_condition\": 22, \"isi diff\": -0.019854298382858834, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 99.099609375, \"lower interval\": -211.92425537109375, \"center interval\": -21.041308641433716, \"higher interval75\": 53.91379165649414, \"lower interval75\": -131.060791015625, \"zero\": 0}, {\"stim_strength\": 1, \"neuron_x_mouse\": \"11\", \"mouse\": \"3\", \"combined_condition\": 23, \"isi diff\": 0.007359094120306421, \"mu_intercept_per_group higher interval\": 15.584847450256348, \"mu_intercept_per_group lower interval\": 2.2272567749023438, \"mu_intercept_per_group center interval\": 6.7830925426096655, \"mu_intercept_per_group higher interval75\": 12.343323707580566, \"mu_intercept_per_group lower interval75\": 3.713416337966919, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"sigma_slope_per_condition higher interval\": null, \"sigma_slope_per_condition lower interval\": null, \"sigma_slope_per_condition center interval\": null, \"higher interval\": 117.85163879394531, \"lower interval\": -207.75613403320312, \"center interval\": -50.186931416392326, \"higher interval75\": 22.130416870117188, \"lower interval75\": -156.6006622314453, \"zero\": 0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "window.chart\n"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "hide_code_all_hidden": false,
  "jupytext": {
   "formats": "ipynb,py:light"
  },
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.10"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
